package com.diagbot.facade;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.diagbot.client.TranServiceClient;
import com.diagbot.dto.HospitalInfoDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.entity.HospitalInfo;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.enums.StatusEnum;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.exception.CommonException;
import com.diagbot.service.impl.HospitalInfoServiceImpl;
import com.diagbot.vo.HospitalInfoVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @Description:
 * @author: wangyu
 * @time: 2018/11/22 13:43
 */
@Component
public class HospitalInfoFacade extends HospitalInfoServiceImpl {

    @Autowired
    TranServiceClient tranServiceClient;

    /**
     * 获取医院信息
     *
     * @param hospitalInfoVO
     * @return
     */
    public List<HospitalInfoDTO> getHospitalInfo(HospitalInfoVO hospitalInfoVO) {
        RespDTO<List<HospitalInfoDTO>> hospitalInfoDTOList = tranServiceClient.getHospitalInfo(hospitalInfoVO);
        if (hospitalInfoDTOList == null || !"0".equals(hospitalInfoDTOList.code)) {
            throw new CommonException(CommonErrorCode.RPC_ERROR,
                    "获取医院信息失败");
        }
        return hospitalInfoDTOList.data;
    }

    /**
     * 通过医院编码获取医院信息
     *
     * @param code 医院编码
     * @return
     */
    public HospitalInfo getHospitalByCode(String code) {
        QueryWrapper<HospitalInfo> queryWrapper = new QueryWrapper<HospitalInfo>();
        queryWrapper.eq("is_deleted", IsDeleteEnum.N.getKey());
        queryWrapper.eq("code", code);
        queryWrapper.eq("status", StatusEnum.Enable.getKey());
        return this.getOne(queryWrapper);
    }

}
