package com.diagbot.facade;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.RequestBody;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.diagbot.client.TranServiceClient;
import com.diagbot.dto.GetTopPatientInfoDTO;
import com.diagbot.dto.PatientInfoDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.entity.DeptInfo;
import com.diagbot.entity.DoctorPageMode;
import com.diagbot.entity.PatientInfo;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.exception.CommonException;
import com.diagbot.service.impl.PatientInfoServiceImpl;
import com.diagbot.vo.GetTopPatientInfoVO;
import com.diagbot.vo.PatientInfoVO;

/**
 * @Description: 患者业务逻辑
 * @author: wangyu
 * @time: 2018/11/19 13:19
 */
@Component
public class PatientInfoFacade extends PatientInfoServiceImpl {

    @Autowired
    private DoctorPageModeFacade doctorPageModeFacade;
    @Autowired
    private DeptInfoFacade deptInfoFacade;
    @Autowired
    TranServiceClient tranServiceClient;

    /**
     * 获取患者信息
     *
     * @param patientInfoVO
     * @return
     */
    public PatientInfoDTO getPatientInfo(PatientInfoVO patientInfoVO) {
        RespDTO<PatientInfoDTO> patientInfoDTO = tranServiceClient.getPatientInfo(patientInfoVO);
        if (patientInfoDTO == null || !"0".equals(patientInfoDTO.code)) {
            throw new CommonException(CommonErrorCode.RPC_ERROR,
                    "获取患者信息失败");
        }
        return patientInfoDTO.data;
    }

    /**
     * 页面顶部病人医生科室信息查询
     *
     * @param getTopPatientInfoVO
     * @return
     */
    public GetTopPatientInfoDTO getTopPatientInfo(@RequestBody GetTopPatientInfoVO getTopPatientInfoVO) {
        RespDTO<GetTopPatientInfoDTO> respDTO = tranServiceClient.getTopPatientInfo(getTopPatientInfoVO);
        if (respDTO == null || !"0".equals(respDTO.code)) {
            throw new CommonException(CommonErrorCode.RPC_ERROR,
                    "页面顶部病人医生科室信息");
        }
        
        GetTopPatientInfoDTO getTopPatientInfoDTO = respDTO.data;

        QueryWrapper<DeptInfo> deptInfoQ = new QueryWrapper<>();
        deptInfoQ.eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("id", getTopPatientInfoDTO.getSelfDeptId());
        DeptInfo deptInfo = deptInfoFacade.getOne(deptInfoQ);
        if (null != deptInfo) {
            getTopPatientInfoDTO.setSelfDeptName(deptInfo.getName());
        }

        QueryWrapper<DoctorPageMode> doctorPageModeQe = new QueryWrapper<>();
        doctorPageModeQe.eq("is_deleted", IsDeleteEnum.N.getKey());
        doctorPageModeQe.eq("doctor_id", getTopPatientInfoDTO.getDoctorId());
        DoctorPageMode doctorPageMode = doctorPageModeFacade.getOne(doctorPageModeQe);
        if (doctorPageMode != null) {
            getTopPatientInfoDTO.setModeClassify(doctorPageMode.getModeClassify());
            getTopPatientInfoDTO.setModeValue(doctorPageMode.getModeValue());
        }
        return getTopPatientInfoDTO;
    }

    /**
     * 通过医院编码、病人编码获取病人信息
     *
     * @param hospitalCode 医院编码
     * @param patientCode  病人编码
     * @return
     */
    public PatientInfo getPatientByCode(String hospitalCode, String patientCode) {
        QueryWrapper<PatientInfo> queryWrapper = new QueryWrapper<PatientInfo>();
        queryWrapper.eq("is_deleted", IsDeleteEnum.N.getKey());
        queryWrapper.eq("hospital_code", hospitalCode);
        queryWrapper.eq("code", patientCode);
        return this.getOne(queryWrapper);
    }

}
